Expr

Enum Expr 

pub enum Expr {
    Num(f64, Option<Span>),
    Str(String, Option<Span>),
    Sym(String, Option<Span>),
    Proc(Proc, Option<Span>),
    List(List, Option<Span>),
    Foreign(Foreign),
    TailCall {
        proc: Proc,
        args: List,
        context: EvalContext,
    },
}
The enum that represents all expression variants in the Rusche language.

Variants



Num(f64, Option<Span>)

A 64-bit floating number value.



Str(String, Option<Span>)

A string value.



Sym(String, Option<Span>)

A symbol value.



Proc(Proc, Option<Span>)

A procedure value. There are 3 types of procedures in Rusche:



List(List, Option<Span>)

A list value. It can be either a cons cell or an empty list.



Foreign(Foreign)

A foreign object value. This is used to store Rust objects in the interpreter.



TailCall

A special case for tail-call optimization. Internal use only.

Fields

proc: Proc
args: List
context: EvalContext

Implementations

Source

impl Expr

pub fn is_atom(&self) -> bool

Returns true if the expression is an atom. Every expresssion that is not a cons cell list is an atom.

pub fn is_nil(&self) -> bool

Return true if the expression is an empty list.

pub fn is_truthy(&self) -> bool

Returns true if the expression can be considered to be truthy. In Rusche, only the empty list (List::Nil) is considered to be falsy.

pub fn span(&self) -> Option<Span>